# WARNING - Generated by {fusen} from dev/flat_full.Rmd: do not edit by hand





#' Get bin expression for a data frame.
#'
#' This function divides the values of a specified column in a data frame into \code{n_bins} bins of equal width.
#' The bin labels are then added as a new column in the data frame.
#'
#' @param dtf_coef A data frame containing the values to be binned.
#' @param n_bins The number of bins to create.
#' 
#' @return A data frame with an additional column named \code{binExpression}, containing the bin labels.
#' @export
#' @examples
#' dtf <- data.frame(mu_ij = c(10, 20, 30, 15, 25, 35, 40, 5, 12, 22))
#' dtf_with_bins <- getBinExpression(dtf, n_bins = 3)
#'
getBinExpression <- function(dtf_coef, n_bins){
      col2bin <- "mu_ij"
      bin_labels <- cut(dtf_coef[[col2bin]], n_bins, labels = paste("BinExpression", 1:n_bins, sep = "_"))
      dtf_coef$binExpression <-  bin_labels     
      return(dtf_coef)
}




#' Generate BE data.
#' 
#' This function generates basal expression data for a given number of genes, in a vector of basal expression values.
#' 
#' @param n_genes The number of genes to generate BE data for.
#' @param basal_expression a numeric vector from which sample BE for eacg genes
#' 
#' @return A data frame containing gene IDs, BE values
#' 
#' @examples
#' generate_basal_expression(n_genes = 100, 10)
#' 
#' @export
generate_basal_expression <- function(n_genes, basal_expression) {
  ## --avoid bug if one value in basal_expr
  pool2sample <- c(basal_expression, basal_expression)
  BE <- sample(x = pool2sample, size = n_genes, replace = T)
  l_geneID <- base::paste("gene", 1:n_genes, sep = "")
  ret <- list(geneID = l_geneID, basalExpr = BE) %>% as.data.frame()
  return(ret)
}



#' Compute basal expresion for gene expression based on the coefficients data frame.
#'
#' This function takes the coefficients data frame \code{dtf_coef} and computes
#' basal expression for gene expression. The scaling factors are generated 
#' using the function \code{generate_basal_expression}.
#'
#' @param dtf_coef A data frame containing the coefficients for gene expression.
#' @param n_genes number of genes in simulation
#' @param basal_expression gene basal expression vector
#'
#' @return A modified data frame \code{dtf_coef} with an additional column containing
#'         the scaling factors for gene expression.
#' @export
#' @examples 
#' list_var <- init_variable()
#' N_GENES <- 5
#' dtf_coef <- getInput2simulation(list_var, N_GENES)
#' dtf_coef <- getLog_qij(dtf_coef)
#' addBasalExpression(dtf_coef, N_GENES, 1)
addBasalExpression <- function(dtf_coef, n_genes, basal_expression){
    BE_df  <-  generate_basal_expression(n_genes, basal_expression )
    dtf_coef <- join_dtf(dtf_coef, BE_df, "geneID", "geneID")
    return(dtf_coef) 
}




