# WARNING - Generated by {fusen} from dev/flat_full.Rmd: do not edit by hand


#' Gets R-squared values for plotting.
#'
#' This function takes a data frame with R-squared and RMSE values,
#' computes position coordinates, and prepares data for plotting.
#' @param data Data frame with R-squared values and RMSE values.
#' @return A data frame with additional columns for labeling in the plot.
#' @export
#' @examples
#' data_metrics <- data.frame(from = c("A", "B", "C"), 
#'                            description = c("Desc1", "Desc2", "Desc3"), 
#'                            R2 = c(0.9, 0.8, 0.7),
#'                            RMSE = c(0.6, 0.2, 0.1))
#' result <- get_metrics_2plot(data_metrics)
get_metrics_2plot <- function(data){
  data$pos_x <- -Inf
  data$pos_y <- Inf
  data$label_italic <- sprintf("italic(R^2) == %1.2f ~ phantom() ~  phantom() ~ italic(RMSE) == %2.2f", round(data$R2, 3), round(data$RMSE, 3))
  data$label_vjust <- as.numeric(factor(data$from))
  return(data)
}


#' Generate an identity term plot and get metrics associated
#'
#' This function generates an identity plot for comparing actual values with estimates
#'
#' @param data_identity A data frame containing comparison results with "actual" and "estimate" columns.
#' @param palette_color dict-like palette default: palette_color = c(DESeq2 = "#500472", HTRfit ="#79cbb8")
#' @param palette_shape Optional parameter that sets the point shape for plots.Default : c(DESeq2 = 17, HTRfit = 19).
#' @param ... additional parameters to pass geom_point aes 
#' @return A ggplot2 identity plot and R2 metric associated
#'
#' @importFrom ggplot2 sym aes geom_point geom_abline facet_wrap theme_bw ggtitle scale_color_manual geom_text scale_shape_manual
#' @importFrom rlang .data new_environment
#' @export
#' @examples
#' comparison_data <- data.frame(
#'        actual = c(1, 2, 3, 4, 5),
#'        estimate = c(0.9, 2.2, 2.8, 4.1, 5.2),
#'        description = rep("Category A", 5),
#'        term = rep("Category A", 5),
#'        from = c("A", "B", "B", "A", "B"))
#' eval_identityTerm(comparison_data, 
#'                  palette_color = c(A = "#500472", B ="#79cbb8"),
#'                  palette_shape = c(A = 17, B = 19))
eval_identityTerm <- function(data_identity, palette_color = c(DESeq2 = "#500472", HTRfit ="#79cbb8"),  
                               palette_shape = c(DESeq2 = 17, HTRfit = 19), ...){

  data_rsquare <- compute_rsquare(data_identity)
  data_rmse <- compute_rmse(data_identity)
  data_metrics <- join_dtf(data_rsquare, data_rmse, k1 = c("from", "description"), k2 = c("from", "description"))
  data_metrics2plot <- get_metrics_2plot(data_metrics)
  
  p <- ggplot2::ggplot(data_identity, mapping = ggplot2::aes(x = .data$actual, y = .data$estimate, col = from, shape = from,  ...) )+
    ggplot2::geom_point(alpha = 0.6, size = 2) +
    ggplot2::geom_abline(intercept = 0, slope = 1, lty = 3, col = 'red', linewidth = 1) +
    ggplot2::facet_wrap(~description, scales = "free") +
    ggplot2::theme_bw()  +
    ggplot2::geom_text(data = data_metrics2plot,
                       mapping = ggplot2::aes(x = pos_x, y = pos_y, label = label_italic, col = from, vjust = label_vjust),
                       parse = TRUE, hjust = -0.3 ) +
    ggplot2::ggtitle("Identity plot") +
    ggplot2::scale_color_manual(values = palette_color ) + 
    ggplot2::scale_shape_manual(values = palette_shape )

  p$plot_env <- rlang::new_environment()

  obj_idTerm <- list(R2 = data_metrics, p = p )

  return(obj_idTerm)
}


