# WARNING - Generated by {fusen} from dev/flat_full.Rmd: do not edit by hand




#' Compute R-squared values for linear regression on grouped data
#'
#' This function takes a data frame, performs linear regression on specified grouping variables,
#' and computes R-squared values for each group.
#'
#' @param data A data frame containing the variables 'actual' and 'estimate' for regression.
#' @param grouping_by A character vector specifying the grouping variables for regression.
#' @return A data frame with columns 'from', 'term', and 'R2' representing the grouping variables
#' and the corresponding R-squared values.
#' @export
#' @examples
#' data <- data.frame(from = c("A", "A", "A", "A"),
#'                    term = c("X", "Y", "X", "Y"),
#'                    actual = c(1, 2, 3, 4),
#'                    estimate = c(1.5, 2.5, 3.5, 4.5))
#' compute_rsquare(data, grouping_by = c("from", "term"))
#'
#' @importFrom data.table data.table
compute_rsquare <- function(data, grouping_by =  c("from", "description") ){
  ## -- convert to data.table
  dat <- data.table::data.table(data)
  ## -- calculate the regression coefficient r^2
  r_square_df <- as.data.frame( 
                              dat[ , summary(lm(actual~estimate))$r.squared, 
                              by = grouping_by ]
                              )
  names(r_square_df)[names(r_square_df) == "V1"] <- "R2"
  return(r_square_df)
}


